@@ -19,8 +19,16 @@ logger.setLevel(logging.INFO)
 @click.option('-e', '--examfile', required=False, default='', type=str, help='Relative or absolute path to the exam file to be loaded')
 def main(sample, examfile) -> None:
     """
-        Use this program to perform a exam/quiz/test using a
-        predefined YML (or YAML) file.
+        \b
+                                       _                      _             _ 
+                                      | |                    (_)           | |
+         _____  ____ _ _ __ ___ ______| |_ ___ _ __ _ __ ___  _ _ __   __ _| |
+        / _ \ \/ / _` | '_ ` _ \______| __/ _ \ '__| '_ ` _ \| | '_ \ / _` | |
+       |  __/>  < (_| | | | | | |     | ||  __/ |  | | | | | | | | | | (_| | |
+        \___/_/\_\__,_|_| |_| |_|      \__\___|_|  |_| |_| |_|_|_| |_|\__,_|_|
+                                                                        
+        Use this little terminal program to perform a exam/quiz/test using a
+        predefined YML (or YAML) file containing exam information.
 
         \b
         Example Usages:
@@ -28,6 +36,9 @@ def main(sample, examfile) -> None:
             exam-terminal -e MyExam.yml
             exam-terminal -examfile ~/Documents/Exams/SomeExam.yaml
             exam-terminal -e "/home/you/review.yml"
+
+        For even more help visit:
+        https://github.com/ismet55555/exam-terminal
     """
     logger.debug(f'--sample = {sample}')
     logger.debug(f'--examfile = {examfile}')
@@ -35,7 +46,8 @@ def main(sample, examfile) -> None:
     # Check if any options have been passed
     if not sample and not examfile:
         ctx = click.get_current_context()
-        ctx.fail("User Input Error: Please specify any option")
+        click.echo(click.style("Uh-Oh! Something's wrong here ...", fg='bright_red', bold=True))
+        ctx.fail(click.style("User Input Error: No exam-terminal options were specified. Please specify any option.", fg='bright_red', bold=True))
 
     # Sample examfile
     exam_filepath = ''
@@ -52,10 +64,15 @@ def main(sample, examfile) -> None:
     # Check if examfile exists
     if not os.path.exists(exam_filepath):
         ctx = click.get_current_context()
-        ctx.fail(f"User Input Error: Exam file specified does not exist: {exam_filepath}")
+        click.echo(click.style("Uh-Oh! Something's wrong here ...", fg='bright_red', bold=True))
+        ctx.fail(click.style(f"User Input Error: The exam file which you specified does not exist: {exam_filepath}", fg='bright_red', bold=True))
 
     # Run exam-terminal
     exitcode = exam_terminal.exam_terminal(exam_filepath=exam_filepath)
+
+    if not exitcode:
+        click.echo(click.style("Done", fg='bright_green', bold=True))
+
     sys.exit(exitcode)
 
 
